
export interface DependencyEntry {
  /**
   * The dependency name
   */
  name: string;
  /**
   * The dependency
   */
  dependency: any;
}

/**
 * A dependency entry
 */
export class SimpleDependencyEntry implements DependencyEntry {

  constructor();

  /**
   * The dependency name
   */
  public name: string;
  /**
   * The dependency
   */
  public dependency: any;

  /**
   * Create a new entry
   * @param name The name of the dependency
   * @param dependency The dependency
   * @return {SimpleDependencyEntry} The entry created
   * @throws {Error} If the dependency cannot be created
   */
  static of(name: string, dependency: any): SimpleDependencyEntry;

  /**
   * Format the name
   * @param name The name to format
   * @return {string} The name formatted
   * @throw {TypeError} If the name is invalid
   */
  static formatName(name): string;

  /**
   * Test if the name is valid
   * @param name The name to test
   * @return {boolean} true if valid, otherwise false
   */
  static isValidName(name): boolean;
}
