import { EventEmitter } from "events";
import {DependencyManager} from "./dependency-manager";

/**
 * Dependency manager which allow to write to one and read from multi
 * manager
 */
export class SimpleMultiDependencyManager extends EventEmitter implements DependencyManager {

  /**
   * The primary dependency manager
   */
  public primary: DependencyManager;

  /**
   * The secondaries manager
   */
  public secondaries: DependencyManager[];

  /**
   * Construct
   * @param primary The primary dependency
   * @param secondaries The secondaries
   * @throws {Error} If the parameter is invalid
   */
  constructor(primary: DependencyManager, secondaries?: DependencyManager[]);

  /**
   * Check if the manager is a valid object
   * @param manager The manager to test
   * @return true if manager is a valid manager
   */
  public static isValidManager(manager: any): boolean;

  /**
   * Check if the secondaries is a valid object
   * @param secondaries The manager to test
   * @return true if manager is a valid manager
   */
  public static isValidSecondaries(secondaries: any): boolean;

  /**
   * Add a secondary manager
   * @param manager A manager to add
   * @throws {Error} If the manager is invalid
   */
  public addSecondary(manager: DependencyManager);

  /**
   * @inheritDoc
   */
  public contains(name: string): boolean;

  /**
   * @inheritDoc
   */
  public get(name: string, defaultValue?: any): any;

  /**
   * @inheritDoc
   */
  public add(name: string, dependency: any): void;

  /**
   * @inheritDoc
   */
  public remove(name: string): void;

  /**
   * @inheritDoc
   */
  public dependencyNames(): string[];
}

