describe('Unit Test - SimpleDependencyEntry', function () {
  const SimpleDependencyEntry = require("./../../../lib/dependency-entry").SimpleDependencyEntry,
    _ = require("lodash");

  describe("When require the manager", function () {
    it("Must be a function", function () {
      expect(SimpleDependencyEntry).toEqual(jasmine.any(Function));
    });
  }); // End when require

  describe("#formatName", function () {
    it("Given no string Then must throw exception", function () {
      _.each([
        {},
        12,
        false,
        undefined
      ], function (arg) {
        expect(() => SimpleDependencyEntry.formatName(arg)).toThrowError();
      });
    });

    it("Given string Then must return expected value", function () {
      expect(SimpleDependencyEntry.formatName(" a ")).toEqual("a");
    });
  }); // #formatName

  describe("#isValidName", function () {
    it("Given no string Then must return false", function () {
      _.each([
        {},
        12,
        false,
        undefined
      ], function (arg) {
        expect(SimpleDependencyEntry.isValidName(arg)).toBeFalsy();
      });
    });

    it("Given string Then must return expected value", function () {
      expect(SimpleDependencyEntry.isValidName(" a ")).toBeTruthy();
    });
  }); // #isValidName

  describe("#of", function () {
    it("Given no string Then must throw exception", function () {
      _.each([
        {},
        12,
        false,
        undefined
      ], function (arg) {
        expect(() => SimpleDependencyEntry.of(arg, undefined)).toThrowError();
      });
    });

    it("Given string as name and dependency", function () {
      const dependency = {},
        name = "az",
        entry = SimpleDependencyEntry.of(name, dependency)
      ;

      expect(entry.name).toBe(name);
      expect(entry.dependency).toBe(dependency);
    });
  }); // #of
});
